from distutils.core import setup

setup(
    name = "Zachs nester",
    version = '1.2.0',
    py_modules = ['nester'],
    author = 'zach',
    author_email = 'mutable@gmail.com',
    url = 'kingtutor.com',
    description = 'nested list printer HFP ch2',
    )
